@@ -20,7 +20,7 @@ use Pod::Simple::LinkSection;	# Core since 5.9.3 (part of Pod::Simple)
 use Storable ();		# Core since 5.7.3
 use Test::Builder ();		# Core since 5.6.2
 
-our $VERSION = '0.012_01';
+our $VERSION = '0.012_02';
 
 our @ISA = qw{ Exporter };
 
@@ -651,9 +651,10 @@ sub _get_installed_doc_info {
 
     # NOTE we have to do this by hand, because Pod::Perldoc searches
     # Perl's bin/ BEFORE the contents of @INC.
+    ( my $file = $module ) =~ s(::)('/)g;
     foreach my $dir ( @{ $self->{add_dir} } ) {
 	foreach my $ext ( '', qw{ .pod .pm } ) {
-	    my $path = "$dir/$module$ext";
+	    my $path = "$dir/$file$ext";
 	    -e $path
 		and -s _
 		and -T _
